@@ -34,13 +34,10 @@ const narcissusWorker = require("narcissus_parser/narcissus_worker");
 const caching = require("http_observer/caching");
 
 const prompt = Cc["@mozilla.org/embedcomp/prompt-service;1"].
-                                    getService(Ci.nsIPromptService);
+  getService(Ci.nsIPromptService);
 
-const tabs = require('tabs');
 
-// check if there's an update on gnu.org.
-// provide a link in widget panel if there is an update.
-var update = require('addon_management/update');
+const tabs = require('sdk/tabs');
 
 /**
  * Stop the httpObserver when the add-on
@@ -48,26 +45,31 @@ var update = require('addon_management/update');
  */
 exports.onUnload = function(reason) {
 
- if (reason == "disable" || 
-     reason == "shutdown" ||
-     reason == "upgrade" ||
-     reason == "downgrade") {
-     // console.log("disable");
+  if (reason == "disable" || 
+      reason == "shutdown" ||
+      reason == "upgrade" ||
+      reason == "downgrade") {
+    // console.log("disable");
+    // 
+    // remove all http notifications
+    httpObserver.removeHttpObserver();
 
-     httpObserver.removeHttpObserver();
-     jsLoadObserver.removeJsLoadObserver();
-     narcissusWorker.stopWorker();
- }
+    // remove dom script loaded observer
+    jsLoadObserver.removeJsLoadObserver();
+
+    // remove worker.
+    narcissusWorker.stopWorker();
+  }
 
 };
 
 exports.onLoad = function () {
-    try {
+  try {
     var clearCache = prompt.confirm(null, "LibreJS installation", "In order for LibreJS to work properly, you should clear the browser cache.\nIf you have tabs and windows opened prior to installing LibreJS, you will have to refresh them for their JavaScript to be analyzed and blocked. Press OK to clear the browser cache.");
     if (clearCache) {
-	caching.clearAllCache();
-    }
-    } catch (e) {
-	console.log(e);
+	    caching.clearAllCache();
     }
+  } catch (e) {
+	  console.log(e);
+  }
 };
\ No newline at end of file
