@@ -18,7 +18,7 @@
  *
  */
 
-var tabs = require("tabs");
+var tabs = require("sdk/tabs");
 var pageMod = require("page-mod");
 
 
